summaryrefslogtreecommitdiffstats
path: root/src/import/chips/p9/procedures/hwp/pm/p9_pm_recovery_ffdc_sgpe.H
diff options
context:
space:
mode:
authorAmit Tendolkar <amit.tendolkar@in.ibm.com>2017-10-30 08:51:54 -0500
committerChristian R. Geddes <crgeddes@us.ibm.com>2017-11-08 19:20:19 -0500
commitc06de50b3c21be4618e820eccfc29adb6577259c (patch)
tree2aab6f38e8236756891efce5b4c5633f988f57f7 /src/import/chips/p9/procedures/hwp/pm/p9_pm_recovery_ffdc_sgpe.H
parent42e96493c5fab5df24c1a4be6ce0df8d65834929 (diff)
downloadtalos-hostboot-c06de50b3c21be4618e820eccfc29adb6577259c.tar.gz
talos-hostboot-c06de50b3c21be4618e820eccfc29adb6577259c.zip
STOP Recovery: Misc infra. updates to enable PM FFDC in HOMER
1. Updated STOP Recovery wrapper for test 2. Enable GPE0/1, shared region sram data collection 3. FIR and OCC register collection support 4. PM FFDC Section Header and Region Inits 5. Defined constants for FFDC region boundary in HOMER 6. Fixed miscellaneous review comments and UT bugs Change-Id: I802e6ddb919efaa09b9ffab5ddd3283d8efa9323 RTC: 179599 CQ: SW406487 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/48987 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: HWSV CI <hwsv-ci+hostboot@us.ibm.com> Reviewed-by: RANGANATHPRASAD G. BRAHMASAMUDRA <prasadbgr@in.ibm.com> Reviewed-by: Prem Shanker Jha <premjha2@in.ibm.com> Tested-by: Hostboot CI <hostboot-ci+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Gregory S. Still <stillgs@us.ibm.com> Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/48992 Reviewed-by: Hostboot Team <hostboot@us.ibm.com> Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP HW <op-hw-jenkins+hostboot@us.ibm.com> Reviewed-by: Christian R. Geddes <crgeddes@us.ibm.com>
Diffstat (limited to 'src/import/chips/p9/procedures/hwp/pm/p9_pm_recovery_ffdc_sgpe.H')
-rw-r--r--src/import/chips/p9/procedures/hwp/pm/p9_pm_recovery_ffdc_sgpe.H20
1 files changed, 12 insertions, 8 deletions
diff --git a/src/import/chips/p9/procedures/hwp/pm/p9_pm_recovery_ffdc_sgpe.H b/src/import/chips/p9/procedures/hwp/pm/p9_pm_recovery_ffdc_sgpe.H
index 227a1f188..640cc0651 100644
--- a/src/import/chips/p9/procedures/hwp/pm/p9_pm_recovery_ffdc_sgpe.H
+++ b/src/import/chips/p9/procedures/hwp/pm/p9_pm_recovery_ffdc_sgpe.H
@@ -55,10 +55,17 @@ namespace p9_stop_recov_ffdc
/// @brief destructor
virtual ~PlatSgpe() { };
+ /// @brief Initializes the SGPE FFDC Sub-Section in HOMER with default header
+ /// @param[in] i_pHomerBuf points to base of P9 HOMER.
+ /// @return fapi2 return code
+ fapi2::ReturnCode init ( void* i_pHomerBuf );
+
/// @brief collects FFDC pertaining to all functional SGPEs in the chip.
/// @param[in] i_pHomerBuf points to base of P9 HOMER.
/// @return fapi2 return code.
- fapi2::ReturnCode collectFfdc( void* i_pHomerBuf );
+ fapi2::ReturnCode collectFfdc( void* i_pHomerBuf,
+ uint8_t i_ffdcType = ALL );
private:
/// @brief collects trace info from SGPE's SRAM buffer.
@@ -83,13 +90,10 @@ namespace p9_stop_recov_ffdc
/// @brief updates the SGPE FFDC Header
///@param[in] i_pHomerBuf points to a location in HOMER meant for SGPE FFDC Header
///param[in] i_ffdcValid bit vector summarizing FFDC validity
///@param[in] i_haltCondition hlat state of SGPE
///@return fapi2 return code.
- ///@note refer to PPE Spec for details on halt state.
-
- fapi2::ReturnCode updateSgpeFfdcHeader( uint8_t * i_pHomerBuf,
- uint8_t i_ffdcValid, uint8_t i_haltCondition );
+ fapi2::ReturnCode updateSgpeFfdcHeader( uint8_t* i_pHomerBuf,
+ uint16_t i_sectionsValid );
///@brief returns type of platform
PmComplexPlatId getPlatType() { return iv_plat; }
OpenPOWER on IntegriCloud
@@ -55,10 +55,17 @@ namespace p9_stop_recov_ffdc
/// @brief collects FFDC pertaining to all functional SGPEs in the chip.
- /// @param[in] i_pHomerBuf points to base of P9 HOMER.
+ /// @param[in] i_pHomerBuf points to base of P9 HOMER.
+ /// @param[in] i_ffdcType indicates the content type to collect
/// @return fapi2 return code.
@@ -83,13 +90,10 @@ namespace p9_stop_recov_ffdc
/// @brief updates the SGPE FFDC Header
///@param[in] i_pHomerBuf points to a location in HOMER meant for SGPE FFDC Header
- ///param[in] i_ffdcValid bit vector summarizing FFDC validity
- ///@param[in] i_haltCondition hlat state of SGPE
+ ///param[in] i_sectionsValid bit vector summarizing FFDC validity
///@return fapi2 return code.